#
# spec file for package python-meld3
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-meld3
# in case supervisor is updated to 4.1.0, this package can be
# removed:
# http://supervisord.org/changes.html
Version:        2.0.1
Release:        1.23
Summary:        HTML/XML templating engine for Python
License:        SUSE-Repoze
Group:          Development/Languages/Python
URL:            https://github.com/supervisor/meld3
Source:         https://files.pythonhosted.org/packages/source/m/meld3/meld3-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Meld3 is an HTML/XML templating system for Python 2.3+ which keeps template
markup and dynamic rendering logic separate from one another. See
http://www.entrian.com/PyMeld for a treatise on the benefits of this pattern.

%prep
%setup -q -n meld3-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt COPYRIGHT.txt README.txt
%{python_sitelib}/*

%changelog
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 2.0.1
  * Fixed a ``DeprecationWarning`` on Python 3.8.
  * in case supervisor is updated to 4.1.0, this package can be
    removed:
    http://supervisord.org/changes.html
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.0:
  - Removed support for older Python versions.  On Python 2, meld3 now
    requires Python 2.7.  On Python 3, meld3 now requires Python 3.4 or later.
  - Added Python 3.7 classifier to ``setup.py``.  No code changes were
    needed for Python 3.7 compatibility.
* Fri Jun 21 2019 pgajdos@suse.com
- run the testsuite in %%check
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Jul 14 2018 jengelh@inai.de
- rpmlint: avoid repeating name in summary.
* Mon Jul  9 2018 dmueller@suse.com
- fix source url
* Mon Aug 28 2017 tbechtold@suse.com
- convert to singlespec
* Sat Mar 25 2017 dmueller@suse.com
- fix licensing
* Tue Dec 13 2016 dmueller@suse.com
- update to 1.0.2:
  - Released to fix an issue where the universal wheel was tagged on PyPI
    as Py Version "2.7" instead of "py2.py3".
  - Fixed a bug introduced in 1.0.0 where unicode strings could not be used
    as attribute values.  Thanks to Terrence Brannon for reporting the issue
    and supplying the initial patch.
  - A ``setup.cfg`` file has been added with a ``[bdist_wheel]`` section to
    mark this package as a universal wheel.
* Tue May 13 2014 hpj@urpla.net
- Update to 1.0.0
  - Dropped support for Python 2.3 / 2.4.  Users of those Python versions
    should pin to earlier releases, (e.g., "meld3<1.0.0dev").
  - Added compatibility with Python 3.2, 3.3, and 3.4.  Thanks to Scott
    Maxwell and Tres Seaver for contributing the patches.
  - Installation now requires setuptools.
  - The optional C extension has been removed.  It was only used internally
    by meld3, was not enabled by default, and did not support all meld3
    features.  The pure Python version has very acceptable performance.
  - The license has been changed from ZPL 2.1 to the BSD-derived Repoze
    license, which is the same license used by Supervisor.
  - Profiling scripts that had been used early in meld3 development have
    been removed.
  - The example scripts example.py and melddiff.py have been removed.  See
    README.rst for the same example that was in example.py and the unit tests
    for examples of the ``diffmeld`` function.
  - Support for using meld3 directly from the command line with
    ``python meld3.py <file> <mutator>`` has been removed.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Dec  6 2012 alexandre@exatati.com.br
- Update to 0.6.10:
  - Fixed a bug where an exception could be raised when escaping certain
    attribute or cdata values.  This was caused by meld3 trying to use
    _encode_entity from xml.etree without importing it first.  Thanks to
    Jorge Puente Sarrin for contributing the patch.
- Aditional changes from 0.6.9:
  - Fixed a test failure that only occurred on some builds of
    Python 2.7 where parsing an unknown entity could raise
    an expat.error instead of SyntaxError.
* Wed Nov  7 2012 saschpe@suse.de
- Update suse macro usage
- No need to BUildRequire python-elementree, the elementree xml
  library is part of python now
* Fri Jan 13 2012 alexandre@exatati.com.br
- Update 0.6.8:
  - Added the C extension source (cmeld3.c) to the release package
    by including it in MANIFEST.in. Thanks to Soren Hansen for
    noticing it was missing from prior releases.
    Running setup.py will now halt on error if a compatible version
    of Python is not detected.
* Fri May 27 2011 alexandre@exatati.com.br
- Update to 0.6.7:
  - Make compatible with Python 2.7 (patch kindly contributed by
    Jonathan Riboux).
- Aditional changes from 0.6.6:
  - Change download location.  This really should be a setuptools
    package so we can upload it to PyPI. No functionality changes.
* Mon Jun 21 2010 alexandre@exatati.com.br
- Initial package (0.6.5) for openSUSE.
